::: openaq.shared.exceptions
    options:
      heading_level: 2
      members:
        - ApiKeyMissingError
        - BadRequestError
        - BadGatewayError
        - ForbiddenError
        - GatewayTimeoutError
        - HTTPRateLimitError
        - NotAuthorizedError
        - NotFoundError
        - TimeoutError
        - RateLimitError
        - ServerError
        - ServiceUnavailableError
        - ValidationError
      show_root_heading: false
      show_source: false
